@@ -26,6 +26,7 @@ from owlready2.namespace       import *
 from owlready2.class_construct import *
 from owlready2.individual      import *
 
+
 _HERMIT_RESULT_REGEXP = re.compile("^([A-Za-z]+)\\( ((?:<(?:[^>]+)>\s*)+) \\)$", re.MULTILINE)
 _HERMIT_PROP_REGEXP   = re.compile("^<([^>]+)> \\(known instances:\s*(.*?)(?:\s*\\|\s*)possible instances:\s*(.*?)\s*\\)", re.MULTILINE)
 
@@ -82,19 +83,19 @@ def _keep_most_specific(s, consider_equivalence = True):
   r = set()
   if consider_equivalence:
     for i in s:
-      if isinstance(i, ClassConstruct): r.add(i)
+      if isinstance(i, Construct): r.add(i)
       else:
         for j in s:
-          if (i is j) or isinstance(j, ClassConstruct): continue
+          if (i is j) or isinstance(j, Construct): continue
           if issubclass(j, i) and ((i.storid < j.storid) or (issubclass_python(j, i))): break
         else:
           r.add(i)
   else:
     for i in s:
-      if isinstance(i, ClassConstruct): r.add(i)
+      if isinstance(i, Construct): r.add(i)
       else:
         for j in s:
-          if (i is j) or isinstance(j, ClassConstruct): continue
+          if (i is j) or isinstance(j, Construct): continue
           if issubclass_python(j, i): break
         else:
           r.add(i)
@@ -244,9 +245,12 @@ def sync_reasoner_pellet(x = None, infer_property_values = False, infer_data_pro
         raise OwlReadyInconsistentOntologyError()
       else:
         raise OwlReadyJavaError("Java error message is:\n%s" % (e.stderr or e.output or b"").decode("utf8"))
-      
-    output = output.decode("utf8").replace("\r","")
 
+    try:
+      output = output.decode("utf8").replace("\r","")
+    except UnicodeDecodeError:
+      output = output.decode("latin").replace("\r","")
+      
     if debug:
       print("* Owlready2 * Pellet took %s seconds" % (time.time() - t0), file = sys.stderr)
       if debug > 1:
@@ -375,10 +379,10 @@ def _apply_reasoning_results(world, ontology, debug, new_parents, new_equivs, en
         if not concept2 in concept1.equivalent_to: concept1.equivalent_to._append(concept2)
         
     for child, parents in new_parents_loaded.items():
-      old = set(parent for parent in child.is_a if not isinstance(parent, ClassConstruct))
+      old = set(parent for parent in child.is_a if not isinstance(parent, Construct))
       new = set(parents)
       
-      #new.update([parent_eq for parent in new for parent_eq in parent.equivalent_to.indirect() if not isinstance(parent, ClassConstruct)])
+      #new.update([parent_eq for parent in new for parent_eq in parent.equivalent_to.indirect() if not isinstance(parent, Construct)])
       
       new.update(old & _TYPES) # Types are not shown by HermiT
       if old == new: continue
@@ -389,7 +393,7 @@ def _apply_reasoning_results(world, ontology, debug, new_parents, new_equivs, en
       new_is_a = list(child.is_a)
       for removed in old - new: new_is_a.remove(removed)
       for added   in new - old: new_is_a.append(added)
-      
+
       child.is_a.reinit(new_is_a)
       
       for child_eq in child.equivalent_to.indirect():
